@@ -28,7 +28,7 @@ sub scan_in_points_of_png_image_file {
 	for (my $i = 0; $i < $reader->{length}; $i+=4) {
 		my $rgba = GFX::Enhancer::PNGRGBA->new($i, $reader->get_byte_interval($i, $i+4)); ### NOTE: ctor takes index here
 		if (($rgba->red | $rgba->green | $rgba->blue) > 0) {
-			push($self->{points}, $rgba);
+			push(@{$self->{points}}, $rgba);
 		}
 	}  
 		 
@@ -37,7 +37,7 @@ sub scan_in_points_of_png_image_file {
 ### private methods
 
 sub scan_in_image {
-	my ($self, 
+	my ($self) = @_;
 
 }
 
